Class: GoCardlessPro::Resources::BankAccountHolderVerification

Inherits:
Object
  • Object
show all
Defined in:
lib/gocardless_pro/resources/bank_account_holder_verification.rb

Overview

Create a bank account holder verification for a bank account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(object, response = nil) ⇒ BankAccountHolderVerification

Initialize a bank_account_holder_verification resource instance

Parameters:

  • object (Hash)

    an object returned from the API



23
24
25
26
27
28
29
30
31
32
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 23

def initialize(object, response = nil)
  @object = object

  @actual_account_name = object['actual_account_name']
  @id = object['id']
  @result = object['result']
  @status = object['status']
  @type = object['type']
  @response = response
end

Instance Attribute Details

#actual_account_nameObject (readonly)

Returns the value of attribute actual_account_name.



15
16
17
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 15

def 
  @actual_account_name
end

#idObject (readonly)

Returns the value of attribute id.



16
17
18
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 16

def id
  @id
end

#resultObject (readonly)

Returns the value of attribute result.



17
18
19
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 17

def result
  @result
end

#statusObject (readonly)

Returns the value of attribute status.



18
19
20
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 18

def status
  @status
end

#typeObject (readonly)

Returns the value of attribute type.



19
20
21
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 19

def type
  @type
end

Instance Method Details

#api_responseObject



34
35
36
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 34

def api_response
  ApiResponse.new(@response)
end

#to_hObject

Provides the bank_account_holder_verification resource as a hash of all its readable attributes



39
40
41
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 39

def to_h
  @object
end