Class: GoCardlessPro::Resources::BillingRequestFlow

Inherits:
Object
  • Object
show all
Defined in:
lib/gocardless_pro/resources/billing_request_flow.rb

Overview

Billing Request Flows can be created to enable a payer to authorise a payment created for a scheme with strong payer authorisation (such as open banking single payments).

Defined Under Namespace

Classes: Links

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(object, response = nil) ⇒ BillingRequestFlow

Initialize a billing_request_flow resource instance



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 38

def initialize(object, response = nil)
  @object = object

  @authorisation_url = object['authorisation_url']
  @auto_fulfil = object['auto_fulfil']
  @created_at = object['created_at']
  @customer_details_captured = object['customer_details_captured']
  @exit_uri = object['exit_uri']
  @expires_at = object['expires_at']
  @id = object['id']
  @language = object['language']
  @links = object['links']
   = object['lock_bank_account']
  @lock_currency = object['lock_currency']
  @lock_customer_details = object['lock_customer_details']
   = object['prefilled_bank_account']
  @prefilled_customer = object['prefilled_customer']
  @redirect_uri = object['redirect_uri']
  @session_token = object['session_token']
  @show_redirect_buttons = object['show_redirect_buttons']
  @show_success_redirect_button = object['show_success_redirect_button']
  @skip_success_screen = object['skip_success_screen']
  @response = response
end

Instance Attribute Details

#authorisation_urlObject (readonly)

Returns the value of attribute authorisation_url.



17
18
19
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 17

def authorisation_url
  @authorisation_url
end

#auto_fulfilObject (readonly)

Returns the value of attribute auto_fulfil.



18
19
20
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 18

def auto_fulfil
  @auto_fulfil
end

#created_atObject (readonly)

Returns the value of attribute created_at.



19
20
21
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 19

def created_at
  @created_at
end

#customer_details_capturedObject (readonly)

Returns the value of attribute customer_details_captured.



20
21
22
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 20

def customer_details_captured
  @customer_details_captured
end

#exit_uriObject (readonly)

Returns the value of attribute exit_uri.



21
22
23
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 21

def exit_uri
  @exit_uri
end

#expires_atObject (readonly)

Returns the value of attribute expires_at.



22
23
24
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 22

def expires_at
  @expires_at
end

#idObject (readonly)

Returns the value of attribute id.



23
24
25
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 23

def id
  @id
end

#languageObject (readonly)

Returns the value of attribute language.



24
25
26
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 24

def language
  @language
end

#lock_bank_accountObject (readonly)

Returns the value of attribute lock_bank_account.



25
26
27
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 25

def 
  
end

#lock_currencyObject (readonly)

Returns the value of attribute lock_currency.



26
27
28
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 26

def lock_currency
  @lock_currency
end

#lock_customer_detailsObject (readonly)

Returns the value of attribute lock_customer_details.



27
28
29
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 27

def lock_customer_details
  @lock_customer_details
end

#prefilled_bank_accountObject (readonly)

Returns the value of attribute prefilled_bank_account.



28
29
30
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 28

def 
  
end

#prefilled_customerObject (readonly)

Returns the value of attribute prefilled_customer.



29
30
31
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 29

def prefilled_customer
  @prefilled_customer
end

#redirect_uriObject (readonly)

Returns the value of attribute redirect_uri.



30
31
32
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 30

def redirect_uri
  @redirect_uri
end

#session_tokenObject (readonly)

Returns the value of attribute session_token.



31
32
33
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 31

def session_token
  @session_token
end

#show_redirect_buttonsObject (readonly)

Returns the value of attribute show_redirect_buttons.



32
33
34
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 32

def show_redirect_buttons
  @show_redirect_buttons
end

#show_success_redirect_buttonObject (readonly)

Returns the value of attribute show_success_redirect_button.



33
34
35
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 33

def show_success_redirect_button
  @show_success_redirect_button
end

#skip_success_screenObject (readonly)

Returns the value of attribute skip_success_screen.



34
35
36
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 34

def skip_success_screen
  @skip_success_screen
end

Instance Method Details

#api_responseObject



63
64
65
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 63

def api_response
  ApiResponse.new(@response)
end

Return the links that the resource has



68
69
70
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 68

def links
  @billing_request_flow_links ||= Links.new(@links)
end

#to_hObject

Provides the billing_request_flow resource as a hash of all its readable attributes



73
74
75
# File 'lib/gocardless_pro/resources/billing_request_flow.rb', line 73

def to_h
  @object
end