Class: GoCardlessPro::Resources::CreditorBankAccount

Inherits:
Object
  • Object
show all
Defined in:
lib/gocardless_pro/resources/creditor_bank_account.rb

Overview

Creditor Bank Accounts hold the bank details of a creditor (https://developer.gocardless.com/api-reference/#core-endpoints-creditors). These are the bank accounts which your payouts (https://developer.gocardless.com/api-reference/#core-endpoints-payouts) will be sent to.

Note that creditor bank accounts must be unique, and so you will encounter a bank_account_exists error if you try to create a duplicate bank account. You may wish to handle this by updating the existing record instead, the ID of which will be provided as links[creditor_bank_account] in the error response.

Restricted: This API is not available for partner integrations.

Defined Under Namespace

Classes: Links

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(object, response = nil) ⇒ CreditorBankAccount

Initialize a creditor_bank_account resource instance

Parameters:

  • object (Hash)

    an object returned from the API



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 41

def initialize(object, response = nil)
  @object = object

  @account_holder_name = object['account_holder_name']
  @account_number_ending = object['account_number_ending']
  @account_type = object['account_type']
  @bank_name = object['bank_name']
  @country_code = object['country_code']
  @created_at = object['created_at']
  @currency = object['currency']
  @enabled = object['enabled']
  @id = object['id']
  @links = object['links']
  @metadata = object['metadata']
  @verification_status = object['verification_status']
  @response = response
end

Instance Attribute Details

#account_holder_nameObject (readonly)

Returns the value of attribute account_holder_name.



27
28
29
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 27

def 
  @account_holder_name
end

#account_number_endingObject (readonly)

Returns the value of attribute account_number_ending.



28
29
30
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 28

def 
  @account_number_ending
end

#account_typeObject (readonly)

Returns the value of attribute account_type.



29
30
31
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 29

def 
  @account_type
end

#bank_nameObject (readonly)

Returns the value of attribute bank_name.



30
31
32
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 30

def bank_name
  @bank_name
end

#country_codeObject (readonly)

Returns the value of attribute country_code.



31
32
33
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 31

def country_code
  @country_code
end

#created_atObject (readonly)

Returns the value of attribute created_at.



32
33
34
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 32

def created_at
  @created_at
end

#currencyObject (readonly)

Returns the value of attribute currency.



33
34
35
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 33

def currency
  @currency
end

#enabledObject (readonly)

Returns the value of attribute enabled.



34
35
36
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 34

def enabled
  @enabled
end

#idObject (readonly)

Returns the value of attribute id.



35
36
37
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 35

def id
  @id
end

#metadataObject (readonly)

Returns the value of attribute metadata.



36
37
38
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 36

def 
  @metadata
end

#verification_statusObject (readonly)

Returns the value of attribute verification_status.



37
38
39
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 37

def verification_status
  @verification_status
end

Instance Method Details

#api_responseObject



59
60
61
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 59

def api_response
  ApiResponse.new(@response)
end

Return the links that the resource has



64
65
66
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 64

def links
  @creditor_bank_account_links ||= Links.new(@links)
end

#to_hObject

Provides the creditor_bank_account resource as a hash of all its readable attributes



69
70
71
# File 'lib/gocardless_pro/resources/creditor_bank_account.rb', line 69

def to_h
  @object
end