Class: GoCardlessPro::Services::BalancesService

Inherits:
BaseService
  • Object
show all
Defined in:
lib/gocardless_pro/services/balances_service.rb

Overview

Service for making requests to the Balance endpoints

Instance Method Summary collapse

Methods inherited from BaseService

#initialize, #make_request, #sub_url

Constructor Details

This class inherits a constructor from GoCardlessPro::Services::BaseService

Instance Method Details

#all(options = {}) ⇒ Object

Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.

Otherwise they will be the body of the request.



35
36
37
38
39
40
# File 'lib/gocardless_pro/services/balances_service.rb', line 35

def all(options = {})
  Paginator.new(
    service: self,
    options: options
  ).enumerator
end

#list(options = {}) ⇒ Object

Returns a [cursor-paginated](#api-usage-cursor-pagination) list of balances for a given creditor. This endpoint is rate limited to 60 requests per minute. Example URL: /balances



17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'lib/gocardless_pro/services/balances_service.rb', line 17

def list(options = {})
  path = '/balances'

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  ListResponse.new(
    response: response,
    unenveloped_body: unenvelope_body(response.body),
    resource_class: Resources::Balance
  )
end