Class: GoCardlessPro::Services::BillingRequestTemplatesService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::BillingRequestTemplatesService
- Defined in:
- lib/gocardless_pro/services/billing_request_templates_service.rb
Overview
Service for making requests to the BillingRequestTemplate endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#create(options = {}) ⇒ Object
Example URL: /billing_request_templates.
-
#get(identity, options = {}) ⇒ Object
Fetches a Billing Request Template Example URL: /billing_request_templates/:identity.
-
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your Billing Request Templates.
-
#update(identity, options = {}) ⇒ Object
Updates a Billing Request Template, which will affect all future Billing Requests created by this template.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
36 37 38 39 40 41 |
# File 'lib/gocardless_pro/services/billing_request_templates_service.rb', line 36 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#create(options = {}) ⇒ Object
Example URL: /billing_request_templates
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/gocardless_pro/services/billing_request_templates_service.rb', line 65 def create( = {}) path = '/billing_request_templates' params = .delete(:params) || {} [:params] = {} [:params][envelope_key] = params [:retry_failures] = true begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::BillingRequestTemplate.new(unenvelope_body(response.body), response) end |
#get(identity, options = {}) ⇒ Object
Fetches a Billing Request Template Example URL: /billing_request_templates/:identity
48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/gocardless_pro/services/billing_request_templates_service.rb', line 48 def get(identity, = {}) path = sub_url('/billing_request_templates/:identity', { 'identity' => identity, }) [:retry_failures] = true response = make_request(:get, path, ) return if response.body.nil? Resources::BillingRequestTemplate.new(unenvelope_body(response.body), response) end |
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your Billing Request Templates. Example URL: /billing_request_templates
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/gocardless_pro/services/billing_request_templates_service.rb', line 18 def list( = {}) path = '/billing_request_templates' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::BillingRequestTemplate ) end |
#update(identity, options = {}) ⇒ Object
Updates a Billing Request Template, which will affect all future Billing Requests created by this template. Example URL: /billing_request_templates/:identity
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/gocardless_pro/services/billing_request_templates_service.rb', line 103 def update(identity, = {}) path = sub_url('/billing_request_templates/:identity', { 'identity' => identity, }) params = .delete(:params) || {} [:params] = {} [:params][envelope_key] = params [:retry_failures] = true response = make_request(:put, path, ) return if response.body.nil? Resources::BillingRequestTemplate.new(unenvelope_body(response.body), response) end |