Class: GoCardlessPro::Services::EventsService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::EventsService
- Defined in:
- lib/gocardless_pro/services/events_service.rb
Overview
Service for making requests to the Event endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#get(identity, options = {}) ⇒ Object
Retrieves the details of a single event.
-
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your events.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
41 42 43 44 45 46 |
# File 'lib/gocardless_pro/services/events_service.rb', line 41 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#get(identity, options = {}) ⇒ Object
Retrieves the details of a single event. Example URL: /events/:identity
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/gocardless_pro/services/events_service.rb', line 53 def get(identity, = {}) path = sub_url('/events/:identity', { 'identity' => identity, }) [:retry_failures] = true response = make_request(:get, path, ) return if response.body.nil? Resources::Event.new(unenvelope_body(response.body), response) end |
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your events.
Important: This endpoint will no longer return events older than 18 months, including when filtering by resource. This takes effect no sooner than 1 August 2026 in sandbox environments, and no sooner than 1 October 2026 in live environments. Example URL: /events
23 24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/gocardless_pro/services/events_service.rb', line 23 def list( = {}) path = '/events' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::Event ) end |