Class: GoCardlessPro::Services::ExportsService

Inherits:
BaseService
  • Object
show all
Defined in:
lib/gocardless_pro/services/exports_service.rb

Overview

Service for making requests to the Export endpoints

Instance Method Summary collapse

Methods inherited from BaseService

#initialize, #make_request, #sub_url

Constructor Details

This class inherits a constructor from GoCardlessPro::Services::BaseService

Instance Method Details

#all(options = {}) ⇒ Object

Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.

Otherwise they will be the body of the request.

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash. If the request is a GET, these will be converted to query parameters.



53
54
55
56
57
58
# File 'lib/gocardless_pro/services/exports_service.rb', line 53

def all(options = {})
  Paginator.new(
    service: self,
    options: options
  ).enumerator
end

#get(identity, options = {}) ⇒ Object

Returns a single export. Example URL: /exports/:identity

Parameters:

  • identity

    # Unique identifier, beginning with “EX”.

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



18
19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/gocardless_pro/services/exports_service.rb', line 18

def get(identity, options = {})
  path = sub_url('/exports/:identity', {
                   'identity' => identity
                 })

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  return if response.body.nil?

  Resources::Export.new(unenvelope_body(response.body), response)
end

#list(options = {}) ⇒ Object

Returns a list of exports which are available for download. Example URL: /exports

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/gocardless_pro/services/exports_service.rb', line 35

def list(options = {})
  path = '/exports'

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  ListResponse.new(
    response: response,
    unenveloped_body: unenvelope_body(response.body),
    resource_class: Resources::Export
  )
end