Class: GoCardlessPro::Services::MandatesService

Inherits:
BaseService
  • Object
show all
Defined in:
lib/gocardless_pro/services/mandates_service.rb

Overview

Service for making requests to the Mandate endpoints

Instance Method Summary collapse

Methods inherited from BaseService

#initialize, #make_request, #sub_url

Constructor Details

This class inherits a constructor from GoCardlessPro::Services::BaseService

Instance Method Details

#all(options = {}) ⇒ Object

Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.

Otherwise they will be the body of the request.

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash. If the request is a GET, these will be converted to query parameters.



71
72
73
74
75
76
# File 'lib/gocardless_pro/services/mandates_service.rb', line 71

def all(options = {})
  Paginator.new(
    service: self,
    options: options
  ).enumerator
end

#cancel(identity, options = {}) ⇒ Object

Immediately cancels a mandate and all associated cancellable payments. Any metadata supplied to this endpoint will be stored on the mandate cancellation event it causes.

This will fail with a cancellation_failed error if the mandate is already cancelled. Example URL: /mandates/:identity/actions/cancel

apply to mandates created before 2016.

Parameters:

  • identity

    Unique identifier, beginning with "MD". Note that this prefix may not

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/gocardless_pro/services/mandates_service.rb', line 133

def cancel(identity, options = {})
  path = sub_url('/mandates/:identity/actions/cancel', {
                   'identity' => identity,
                 })

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params]['data'] = params

  options[:retry_failures] = false

  begin
    response = make_request(:post, path, options)

    # Response doesn't raise any errors until #body is called
    response.tap(&:body)
  rescue InvalidStateError => e
    if e.idempotent_creation_conflict?
      case @api_service.on_idempotency_conflict
      when :raise
        raise IdempotencyConflict.new(e.error)
      when :fetch
        return get(e.conflicting_resource_id)
      end
    end

    raise e
  end

  return if response.body.nil?

  Resources::Mandate.new(unenvelope_body(response.body), response)
end

#create(options = {}) ⇒ Object

Creates a new mandate object. Example URL: /mandates

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/gocardless_pro/services/mandates_service.rb', line 16

def create(options = {})
  path = '/mandates'

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params][envelope_key] = params

  options[:retry_failures] = true

  begin
    response = make_request(:post, path, options)

    # Response doesn't raise any errors until #body is called
    response.tap(&:body)
  rescue InvalidStateError => e
    if e.idempotent_creation_conflict?
      case @api_service.on_idempotency_conflict
      when :raise
        raise IdempotencyConflict.new(e.error)
      when :fetch
        return get(e.conflicting_resource_id)
      end
    end

    raise e
  end

  return if response.body.nil?

  Resources::Mandate.new(unenvelope_body(response.body), response)
end

#get(identity, options = {}) ⇒ Object

Retrieves the details of an existing mandate. Example URL: /mandates/:identity

apply to mandates created before 2016.

Parameters:

  • identity

    Unique identifier, beginning with "MD". Note that this prefix may not

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/gocardless_pro/services/mandates_service.rb', line 84

def get(identity, options = {})
  path = sub_url('/mandates/:identity', {
                   'identity' => identity,
                 })

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  return if response.body.nil?

  Resources::Mandate.new(unenvelope_body(response.body), response)
end

#list(options = {}) ⇒ Object

Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your mandates. Example URL: /mandates

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/gocardless_pro/services/mandates_service.rb', line 53

def list(options = {})
  path = '/mandates'

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  ListResponse.new(
    response: response,
    unenveloped_body: unenvelope_body(response.body),
    resource_class: Resources::Mandate
  )
end

#reinstate(identity, options = {}) ⇒ Object

Reinstates a cancelled or expired mandate to the banks. You will receive a resubmission_requested webhook, but after that reinstating the mandate follows the same process as its initial creation, so you will receive a submitted webhook, followed by a reinstated or failed webhook up to two working days later. Any metadata supplied to this endpoint will be stored on the resubmission_requested event it causes.

This will fail with a mandate_not_inactive error if the mandate is already being submitted, or is active.

Mandates can be resubmitted up to 10 times. Example URL: /mandates/:identity/actions/reinstate

apply to mandates created before 2016.

Parameters:

  • identity

    Unique identifier, beginning with "MD". Note that this prefix may not

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/gocardless_pro/services/mandates_service.rb', line 183

def reinstate(identity, options = {})
  path = sub_url('/mandates/:identity/actions/reinstate', {
                   'identity' => identity,
                 })

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params]['data'] = params

  options[:retry_failures] = false

  begin
    response = make_request(:post, path, options)

    # Response doesn't raise any errors until #body is called
    response.tap(&:body)
  rescue InvalidStateError => e
    if e.idempotent_creation_conflict?
      case @api_service.on_idempotency_conflict
      when :raise
        raise IdempotencyConflict.new(e.error)
      when :fetch
        return get(e.conflicting_resource_id)
      end
    end

    raise e
  end

  return if response.body.nil?

  Resources::Mandate.new(unenvelope_body(response.body), response)
end

#update(identity, options = {}) ⇒ Object

Updates a mandate object. This accepts only the metadata parameter. Example URL: /mandates/:identity

apply to mandates created before 2016.

Parameters:

  • identity

    Unique identifier, beginning with "MD". Note that this prefix may not

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/gocardless_pro/services/mandates_service.rb', line 104

def update(identity, options = {})
  path = sub_url('/mandates/:identity', {
                   'identity' => identity,
                 })

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params][envelope_key] = params

  options[:retry_failures] = true

  response = make_request(:put, path, options)

  return if response.body.nil?

  Resources::Mandate.new(unenvelope_body(response.body), response)
end