Class: GoCardlessPro::Services::OutboundPaymentImportEntriesService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::OutboundPaymentImportEntriesService
- Defined in:
- lib/gocardless_pro/services/outbound_payment_import_entries_service.rb
Overview
Service for making requests to the OutboundPaymentImportEntry endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of the entries for a given outbound payment import.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
36 37 38 39 40 41 |
# File 'lib/gocardless_pro/services/outbound_payment_import_entries_service.rb', line 36 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of the entries for a given outbound payment import. Example URL: /outbound_payment_import_entries
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/gocardless_pro/services/outbound_payment_import_entries_service.rb', line 18 def list( = {}) path = '/outbound_payment_import_entries' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::OutboundPaymentImportEntry ) end |