Class: GoCardlessPro::Services::OutboundPaymentsService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::OutboundPaymentsService
- Defined in:
- lib/gocardless_pro/services/outbound_payments_service.rb
Overview
Service for making requests to the OutboundPayment endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#approve(identity, options = {}) ⇒ Object
Approves an outbound payment.
-
#cancel(identity, options = {}) ⇒ Object
Cancels an outbound payment.
-
#create(options = {}) ⇒ Object
Example URL: /outbound_payments.
-
#get(identity, options = {}) ⇒ Object
Fetches an outbound_payment by ID Example URL: /outbound_payments/:identity.
-
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of outbound payments.
-
#stats(options = {}) ⇒ Object
Retrieve aggregate statistics on outbound payments.
-
#update(identity, options = {}) ⇒ Object
Updates an outbound payment object.
-
#withdraw(options = {}) ⇒ Object
Creates an outbound payment to your verified business bank account as the recipient.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
208 209 210 211 212 213 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 208 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#approve(identity, options = {}) ⇒ Object
Approves an outbound payment. Only outbound payments with the "pending_approval" status can be approved. Example URL: /outbound_payments/:identity/actions/approve
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 132 def approve(identity, = {}) path = sub_url('/outbound_payments/:identity/actions/approve', { 'identity' => identity, }) params = .delete(:params) || {} [:params] = {} [:params]['data'] = params [:retry_failures] = false begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::OutboundPayment.new(unenvelope_body(response.body), response) end |
#cancel(identity, options = {}) ⇒ Object
Cancels an outbound payment. Only outbound payments with either verifying,
pending_approval, or scheduled status can be cancelled.
Once an outbound payment is executing, the money moving process has begun
and cannot be reversed.
Example URL: /outbound_payments/:identity/actions/cancel
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 92 def cancel(identity, = {}) path = sub_url('/outbound_payments/:identity/actions/cancel', { 'identity' => identity, }) params = .delete(:params) || {} [:params] = {} [:params]['data'] = params [:retry_failures] = false begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::OutboundPayment.new(unenvelope_body(response.body), response) end |
#create(options = {}) ⇒ Object
Example URL: /outbound_payments
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 16 def create( = {}) path = '/outbound_payments' params = .delete(:params) || {} [:params] = {} [:params][envelope_key] = params [:retry_failures] = true begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::OutboundPayment.new(unenvelope_body(response.body), response) end |
#get(identity, options = {}) ⇒ Object
Fetches an outbound_payment by ID Example URL: /outbound_payments/:identity
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 171 def get(identity, = {}) path = sub_url('/outbound_payments/:identity', { 'identity' => identity, }) [:retry_failures] = true response = make_request(:get, path, ) return if response.body.nil? Resources::OutboundPayment.new(unenvelope_body(response.body), response) end |
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of outbound payments. Example URL: /outbound_payments
190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 190 def list( = {}) path = '/outbound_payments' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::OutboundPayment ) end |
#stats(options = {}) ⇒ Object
Retrieve aggregate statistics on outbound payments. Example URL: /outbound_payments/stats
241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 241 def stats( = {}) path = '/outbound_payments/stats' [:retry_failures] = false response = make_request(:get, path, ) return if response.body.nil? Resources::OutboundPayment.new(unenvelope_body(response.body), response) end |
#update(identity, options = {}) ⇒ Object
Updates an outbound payment object. This accepts only the metadata parameter. Example URL: /outbound_payments/:identity
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 220 def update(identity, = {}) path = sub_url('/outbound_payments/:identity', { 'identity' => identity, }) params = .delete(:params) || {} [:params] = {} [:params][envelope_key] = params [:retry_failures] = true response = make_request(:put, path, ) return if response.body.nil? Resources::OutboundPayment.new(unenvelope_body(response.body), response) end |
#withdraw(options = {}) ⇒ Object
Creates an outbound payment to your verified business bank account as the recipient. Example URL: /outbound_payments/withdrawal
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/gocardless_pro/services/outbound_payments_service.rb', line 52 def withdraw( = {}) path = '/outbound_payments/withdrawal' params = .delete(:params) || {} [:params] = {} [:params]['data'] = params [:retry_failures] = false begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::OutboundPayment.new(unenvelope_body(response.body), response) end |