Class: GoCardlessPro::Services::PaymentAccountsService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::PaymentAccountsService
- Defined in:
- lib/gocardless_pro/services/payment_accounts_service.rb
Overview
Service for making requests to the PaymentAccount endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#get(identity, options = {}) ⇒ Object
Retrieves the details of an existing payment account.
-
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your payment accounts.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
55 56 57 58 59 60 |
# File 'lib/gocardless_pro/services/payment_accounts_service.rb', line 55 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#get(identity, options = {}) ⇒ Object
Retrieves the details of an existing payment account. Example URL: /payment_accounts/:identity
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/gocardless_pro/services/payment_accounts_service.rb', line 18 def get(identity, = {}) path = sub_url('/payment_accounts/:identity', { 'identity' => identity, }) [:retry_failures] = true response = make_request(:get, path, ) return if response.body.nil? Resources::PaymentAccount.new(unenvelope_body(response.body), response) end |
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your payment accounts. Example URL: /payment_accounts
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/gocardless_pro/services/payment_accounts_service.rb', line 37 def list( = {}) path = '/payment_accounts' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::PaymentAccount ) end |