Class: GoCardlessPro::Services::PaymentsService

Inherits:
BaseService
  • Object
show all
Defined in:
lib/gocardless_pro/services/payments_service.rb

Overview

Service for making requests to the Payment endpoints

Instance Method Summary collapse

Methods inherited from BaseService

#initialize, #make_request, #sub_url

Constructor Details

This class inherits a constructor from GoCardlessPro::Services::BaseService

Instance Method Details

#all(options = {}) ⇒ Object

Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.

Otherwise they will be the body of the request.

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash. If the request is a GET, these will be converted to query parameters.



77
78
79
80
81
82
# File 'lib/gocardless_pro/services/payments_service.rb', line 77

def all(options = {})
  Paginator.new(
    service: self,
    options: options
  ).enumerator
end

#cancel(identity, options = {}) ⇒ Object

Cancels the payment if it has not already been submitted to the banks. Any metadata supplied to this endpoint will be stored on the payment cancellation event it causes.

This will fail with a cancellation_failed error unless the payment's status is pending_submission. Example URL: /payments/:identity/actions/cancel

Parameters:

  • identity

    Unique identifier, beginning with "PM".

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/gocardless_pro/services/payments_service.rb', line 136

def cancel(identity, options = {})
  path = sub_url('/payments/:identity/actions/cancel', {
                   'identity' => identity,
                 })

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params]['data'] = params

  options[:retry_failures] = false

  begin
    response = make_request(:post, path, options)

    # Response doesn't raise any errors until #body is called
    response.tap(&:body)
  rescue InvalidStateError => e
    if e.idempotent_creation_conflict?
      case @api_service.on_idempotency_conflict
      when :raise
        raise IdempotencyConflict.new(e.error)
      when :fetch
        return get(e.conflicting_resource_id)
      end
    end

    raise e
  end

  return if response.body.nil?

  Resources::Payment.new(unenvelope_body(response.body), response)
end

#create(options = {}) ⇒ Object

Creates a new payment object.

This fails with a mandate_is_inactive error if the linked mandate (https://developer.gocardless.com/api-reference/#core-endpoints-mandates) is cancelled or has failed. Payments can be created against mandates with status of: pending_customer_approval, pending_submission, submitted, and active. Example URL: /payments

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/gocardless_pro/services/payments_service.rb', line 22

def create(options = {})
  path = '/payments'

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params][envelope_key] = params

  options[:retry_failures] = true

  begin
    response = make_request(:post, path, options)

    # Response doesn't raise any errors until #body is called
    response.tap(&:body)
  rescue InvalidStateError => e
    if e.idempotent_creation_conflict?
      case @api_service.on_idempotency_conflict
      when :raise
        raise IdempotencyConflict.new(e.error)
      when :fetch
        return get(e.conflicting_resource_id)
      end
    end

    raise e
  end

  return if response.body.nil?

  Resources::Payment.new(unenvelope_body(response.body), response)
end

#get(identity, options = {}) ⇒ Object

Retrieves the details of a single existing payment. Example URL: /payments/:identity

Parameters:

  • identity

    Unique identifier, beginning with "PM".

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/gocardless_pro/services/payments_service.rb', line 89

def get(identity, options = {})
  path = sub_url('/payments/:identity', {
                   'identity' => identity,
                 })

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  return if response.body.nil?

  Resources::Payment.new(unenvelope_body(response.body), response)
end

#list(options = {}) ⇒ Object

Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your payments. Example URL: /payments

Parameters:

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/gocardless_pro/services/payments_service.rb', line 59

def list(options = {})
  path = '/payments'

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  ListResponse.new(
    response: response,
    unenveloped_body: unenvelope_body(response.body),
    resource_class: Resources::Payment
  )
end

#retry(identity, options = {}) ⇒ Object

Retries a failed payment if the underlying mandate is active. You will receive a resubmission_requested webhook, but after that retrying the payment follows the same process as its initial creation, so you will receive a submitted webhook, followed by a confirmed or failed event. Any metadata supplied to this endpoint will be stored against the payment submission event it causes.

This will return a retry_failed error if the payment has not failed.

Payments can be retried up to 3 times. Example URL: /payments/:identity/actions/retry

Parameters:

  • identity

    Unique identifier, beginning with "PM".

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/gocardless_pro/services/payments_service.rb', line 184

def retry(identity, options = {})
  path = sub_url('/payments/:identity/actions/retry', {
                   'identity' => identity,
                 })

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params]['data'] = params

  options[:retry_failures] = false

  begin
    response = make_request(:post, path, options)

    # Response doesn't raise any errors until #body is called
    response.tap(&:body)
  rescue InvalidStateError => e
    if e.idempotent_creation_conflict?
      case @api_service.on_idempotency_conflict
      when :raise
        raise IdempotencyConflict.new(e.error)
      when :fetch
        return get(e.conflicting_resource_id)
      end
    end

    raise e
  end

  return if response.body.nil?

  Resources::Payment.new(unenvelope_body(response.body), response)
end

#update(identity, options = {}) ⇒ Object

Updates a payment object. This accepts only the metadata parameter. Example URL: /payments/:identity

Parameters:

  • identity

    Unique identifier, beginning with "PM".

  • options (Hash) (defaults to: {})

    parameters as a hash, under a params key.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/gocardless_pro/services/payments_service.rb', line 108

def update(identity, options = {})
  path = sub_url('/payments/:identity', {
                   'identity' => identity,
                 })

  params = options.delete(:params) || {}
  options[:params] = {}
  options[:params][envelope_key] = params

  options[:retry_failures] = true

  response = make_request(:put, path, options)

  return if response.body.nil?

  Resources::Payment.new(unenvelope_body(response.body), response)
end