Class: GoCardlessPro::Services::PayoutItemsService

Inherits:
BaseService
  • Object
show all
Defined in:
lib/gocardless_pro/services/payout_items_service.rb

Overview

Service for making requests to the PayoutItem endpoints

Instance Method Summary collapse

Methods inherited from BaseService

#initialize, #make_request, #sub_url

Constructor Details

This class inherits a constructor from GoCardlessPro::Services::BaseService

Instance Method Details

#all(options = {}) ⇒ Object

Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.

Otherwise they will be the body of the request.



40
41
42
43
44
45
# File 'lib/gocardless_pro/services/payout_items_service.rb', line 40

def all(options = {})
  Paginator.new(
    service: self,
    options: options
  ).enumerator
end

#list(options = {}) ⇒ Object

Returns a [cursor-paginated](#api-usage-cursor-pagination) list of items in the payout.

<strong>This endpoint only serves requests for payouts created in the last 6 months. Requests for older payouts will return an HTTP status 410 Gone.</strong>

Example URL: /payout_items



22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/gocardless_pro/services/payout_items_service.rb', line 22

def list(options = {})
  path = '/payout_items'

  options[:retry_failures] = true

  response = make_request(:get, path, options)

  ListResponse.new(
    response: response,
    unenveloped_body: unenvelope_body(response.body),
    resource_class: Resources::PayoutItem
  )
end