Class: GoCardlessPro::Resources::BankAccountHolderVerification
- Inherits:
-
Object
- Object
- GoCardlessPro::Resources::BankAccountHolderVerification
- Defined in:
- lib/gocardless_pro/resources/bank_account_holder_verification.rb
Overview
Create a bank account holder verification for a bank account.
Instance Attribute Summary collapse
-
#actual_account_name ⇒ Object
readonly
Returns the value of attribute actual_account_name.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#result ⇒ Object
readonly
Returns the value of attribute result.
-
#status ⇒ Object
readonly
Returns the value of attribute status.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
Instance Method Summary collapse
- #api_response ⇒ Object
-
#initialize(object, response = nil) ⇒ BankAccountHolderVerification
constructor
Initialize a bank_account_holder_verification resource instance.
-
#to_h ⇒ Object
Provides the bank_account_holder_verification resource as a hash of all its readable attributes.
Constructor Details
#initialize(object, response = nil) ⇒ BankAccountHolderVerification
Initialize a bank_account_holder_verification resource instance
23 24 25 26 27 28 29 30 31 32 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 23 def initialize(object, response = nil) @object = object @actual_account_name = object['actual_account_name'] @id = object['id'] @result = object['result'] @status = object['status'] @type = object['type'] @response = response end |
Instance Attribute Details
#actual_account_name ⇒ Object (readonly)
Returns the value of attribute actual_account_name.
15 16 17 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 15 def actual_account_name @actual_account_name end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
16 17 18 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 16 def id @id end |
#result ⇒ Object (readonly)
Returns the value of attribute result.
17 18 19 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 17 def result @result end |
#status ⇒ Object (readonly)
Returns the value of attribute status.
18 19 20 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 18 def status @status end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
19 20 21 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 19 def type @type end |
Instance Method Details
#api_response ⇒ Object
34 35 36 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 34 def api_response ApiResponse.new(@response) end |
#to_h ⇒ Object
Provides the bank_account_holder_verification resource as a hash of all its readable attributes
39 40 41 |
# File 'lib/gocardless_pro/resources/bank_account_holder_verification.rb', line 39 def to_h @object end |