Class: GoCardlessPro::Resources::BankDetailsLookup
- Inherits:
-
Object
- Object
- GoCardlessPro::Resources::BankDetailsLookup
- Defined in:
- lib/gocardless_pro/resources/bank_details_lookup.rb
Overview
Look up the name and reachability of a bank account.
Instance Attribute Summary collapse
-
#available_debit_schemes ⇒ Object
readonly
Returns the value of attribute available_debit_schemes.
-
#bank_name ⇒ Object
readonly
Returns the value of attribute bank_name.
-
#bic ⇒ Object
readonly
Returns the value of attribute bic.
Instance Method Summary collapse
- #api_response ⇒ Object
-
#initialize(object, response = nil) ⇒ BankDetailsLookup
constructor
Initialize a bank_details_lookup resource instance.
-
#to_h ⇒ Object
Provides the bank_details_lookup resource as a hash of all its readable attributes.
Constructor Details
#initialize(object, response = nil) ⇒ BankDetailsLookup
Initialize a bank_details_lookup resource instance
21 22 23 24 25 26 27 28 |
# File 'lib/gocardless_pro/resources/bank_details_lookup.rb', line 21 def initialize(object, response = nil) @object = object @available_debit_schemes = object['available_debit_schemes'] @bank_name = object['bank_name'] @bic = object['bic'] @response = response end |
Instance Attribute Details
#available_debit_schemes ⇒ Object (readonly)
Returns the value of attribute available_debit_schemes.
15 16 17 |
# File 'lib/gocardless_pro/resources/bank_details_lookup.rb', line 15 def available_debit_schemes @available_debit_schemes end |
#bank_name ⇒ Object (readonly)
Returns the value of attribute bank_name.
16 17 18 |
# File 'lib/gocardless_pro/resources/bank_details_lookup.rb', line 16 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Returns the value of attribute bic.
17 18 19 |
# File 'lib/gocardless_pro/resources/bank_details_lookup.rb', line 17 def bic @bic end |
Instance Method Details
#api_response ⇒ Object
30 31 32 |
# File 'lib/gocardless_pro/resources/bank_details_lookup.rb', line 30 def api_response ApiResponse.new(@response) end |
#to_h ⇒ Object
Provides the bank_details_lookup resource as a hash of all its readable attributes
35 36 37 |
# File 'lib/gocardless_pro/resources/bank_details_lookup.rb', line 35 def to_h @object end |