Class: GoCardlessPro::Resources::OutboundPaymentImportEntry
- Inherits:
-
Object
- Object
- GoCardlessPro::Resources::OutboundPaymentImportEntry
- Defined in:
- lib/gocardless_pro/resources/outbound_payment_import_entry.rb
Overview
Import Entries are the individual rows of an outbound payment import, representing each payment to be created.
Defined Under Namespace
Classes: Links
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Returns the value of attribute amount.
-
#created_at ⇒ Object
readonly
Returns the value of attribute created_at.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#metadata ⇒ Object
readonly
Returns the value of attribute metadata.
-
#processed_at ⇒ Object
readonly
Returns the value of attribute processed_at.
-
#reference ⇒ Object
readonly
Returns the value of attribute reference.
-
#scheme ⇒ Object
readonly
Returns the value of attribute scheme.
-
#validation_errors ⇒ Object
readonly
Returns the value of attribute validation_errors.
-
#verification_result ⇒ Object
readonly
Returns the value of attribute verification_result.
Instance Method Summary collapse
- #api_response ⇒ Object
-
#initialize(object, response = nil) ⇒ OutboundPaymentImportEntry
constructor
Initialize a outbound_payment_import_entry resource instance.
-
#links ⇒ Object
Return the links that the resource has.
-
#to_h ⇒ Object
Provides the outbound_payment_import_entry resource as a hash of all its readable attributes.
Constructor Details
#initialize(object, response = nil) ⇒ OutboundPaymentImportEntry
Initialize a outbound_payment_import_entry resource instance
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 28 def initialize(object, response = nil) @object = object @amount = object['amount'] @created_at = object['created_at'] @id = object['id'] @links = object['links'] @metadata = object['metadata'] @processed_at = object['processed_at'] @reference = object['reference'] @scheme = object['scheme'] @validation_errors = object['validation_errors'] @verification_result = object['verification_result'] @response = response end |
Instance Attribute Details
#amount ⇒ Object (readonly)
Returns the value of attribute amount.
16 17 18 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 16 def amount @amount end |
#created_at ⇒ Object (readonly)
Returns the value of attribute created_at.
17 18 19 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 17 def created_at @created_at end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
18 19 20 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 18 def id @id end |
#metadata ⇒ Object (readonly)
Returns the value of attribute metadata.
19 20 21 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 19 def @metadata end |
#processed_at ⇒ Object (readonly)
Returns the value of attribute processed_at.
20 21 22 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 20 def processed_at @processed_at end |
#reference ⇒ Object (readonly)
Returns the value of attribute reference.
21 22 23 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 21 def reference @reference end |
#scheme ⇒ Object (readonly)
Returns the value of attribute scheme.
22 23 24 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 22 def scheme @scheme end |
#validation_errors ⇒ Object (readonly)
Returns the value of attribute validation_errors.
23 24 25 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 23 def validation_errors @validation_errors end |
#verification_result ⇒ Object (readonly)
Returns the value of attribute verification_result.
24 25 26 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 24 def verification_result @verification_result end |
Instance Method Details
#api_response ⇒ Object
44 45 46 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 44 def api_response ApiResponse.new(@response) end |
#links ⇒ Object
Return the links that the resource has
49 50 51 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 49 def links @outbound_payment_import_entry_links ||= Links.new(@links) end |
#to_h ⇒ Object
Provides the outbound_payment_import_entry resource as a hash of all its readable attributes
54 55 56 |
# File 'lib/gocardless_pro/resources/outbound_payment_import_entry.rb', line 54 def to_h @object end |