Class: GoCardlessPro::Resources::VerificationDetail
- Inherits:
-
Object
- Object
- GoCardlessPro::Resources::VerificationDetail
- Defined in:
- lib/gocardless_pro/resources/verification_detail.rb
Overview
Verification details represent any information needed by GoCardless to verify a creditor.
Restricted: These endpoints are restricted to customers who want to collect their merchant's verification details and pass them to GoCardless via our API. Please get in touch (mailto:help@gocardless.com) if you wish to enable this feature on your account.
Defined Under Namespace
Classes: Links
Instance Attribute Summary collapse
-
#address_line1 ⇒ Object
readonly
Returns the value of attribute address_line1.
-
#address_line2 ⇒ Object
readonly
Returns the value of attribute address_line2.
-
#address_line3 ⇒ Object
readonly
Returns the value of attribute address_line3.
-
#city ⇒ Object
readonly
Returns the value of attribute city.
-
#company_number ⇒ Object
readonly
Returns the value of attribute company_number.
-
#country_code ⇒ Object
readonly
Returns the value of attribute country_code.
-
#description ⇒ Object
readonly
Returns the value of attribute description.
-
#directors ⇒ Object
readonly
Returns the value of attribute directors.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#postal_code ⇒ Object
readonly
Returns the value of attribute postal_code.
-
#region ⇒ Object
readonly
Returns the value of attribute region.
Instance Method Summary collapse
- #api_response ⇒ Object
-
#initialize(object, response = nil) ⇒ VerificationDetail
constructor
Initialize a verification_detail resource instance.
-
#links ⇒ Object
Return the links that the resource has.
-
#to_h ⇒ Object
Provides the verification_detail resource as a hash of all its readable attributes.
Constructor Details
#initialize(object, response = nil) ⇒ VerificationDetail
Initialize a verification_detail resource instance
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 39 def initialize(object, response = nil) @object = object @address_line1 = object['address_line1'] @address_line2 = object['address_line2'] @address_line3 = object['address_line3'] @city = object['city'] @company_number = object['company_number'] @country_code = object['country_code'] @description = object['description'] @directors = object['directors'] @links = object['links'] @name = object['name'] @postal_code = object['postal_code'] @region = object['region'] @response = response end |
Instance Attribute Details
#address_line1 ⇒ Object (readonly)
Returns the value of attribute address_line1.
25 26 27 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 25 def address_line1 @address_line1 end |
#address_line2 ⇒ Object (readonly)
Returns the value of attribute address_line2.
26 27 28 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 26 def address_line2 @address_line2 end |
#address_line3 ⇒ Object (readonly)
Returns the value of attribute address_line3.
27 28 29 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 27 def address_line3 @address_line3 end |
#city ⇒ Object (readonly)
Returns the value of attribute city.
28 29 30 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 28 def city @city end |
#company_number ⇒ Object (readonly)
Returns the value of attribute company_number.
29 30 31 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 29 def company_number @company_number end |
#country_code ⇒ Object (readonly)
Returns the value of attribute country_code.
30 31 32 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 30 def country_code @country_code end |
#description ⇒ Object (readonly)
Returns the value of attribute description.
31 32 33 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 31 def description @description end |
#directors ⇒ Object (readonly)
Returns the value of attribute directors.
32 33 34 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 32 def directors @directors end |
#name ⇒ Object (readonly)
Returns the value of attribute name.
33 34 35 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 33 def name @name end |
#postal_code ⇒ Object (readonly)
Returns the value of attribute postal_code.
34 35 36 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 34 def postal_code @postal_code end |
#region ⇒ Object (readonly)
Returns the value of attribute region.
35 36 37 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 35 def region @region end |
Instance Method Details
#api_response ⇒ Object
57 58 59 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 57 def api_response ApiResponse.new(@response) end |
#links ⇒ Object
Return the links that the resource has
62 63 64 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 62 def links @verification_detail_links ||= Links.new(@links) end |
#to_h ⇒ Object
Provides the verification_detail resource as a hash of all its readable attributes
67 68 69 |
# File 'lib/gocardless_pro/resources/verification_detail.rb', line 67 def to_h @object end |