Class: GoCardlessPro::Services::CustomerBankAccountsService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::CustomerBankAccountsService
- Defined in:
- lib/gocardless_pro/services/customer_bank_accounts_service.rb
Overview
Service for making requests to the CustomerBankAccount endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#create(options = {}) ⇒ Object
Creates a new customer bank account object.
-
#disable(identity, options = {}) ⇒ Object
Immediately cancels all associated mandates and cancellable payments.
-
#get(identity, options = {}) ⇒ Object
Retrieves the details of an existing bank account.
-
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your bank accounts.
-
#update(identity, options = {}) ⇒ Object
Updates a customer bank account object.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
86 87 88 89 90 91 |
# File 'lib/gocardless_pro/services/customer_bank_accounts_service.rb', line 86 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#create(options = {}) ⇒ Object
Creates a new customer bank account object.
There are three different ways to supply bank account details:
- Local details (https://developer.gocardless.com/api-reference/#appendix-local-bank-details)
- IBAN
- Customer Bank Account Tokens (https://developer.gocardless.com/api-reference/#javascript-flow-create-a-customer-bank-account-token)
For more information on the different fields required in each country, see local bank details (https://developer.gocardless.com/api-reference/#appendix-local-bank-details). Example URL: /customer_bank_accounts
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/gocardless_pro/services/customer_bank_accounts_service.rb', line 31 def create( = {}) path = '/customer_bank_accounts' params = .delete(:params) || {} [:params] = {} [:params][envelope_key] = params [:retry_failures] = true begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::CustomerBankAccount.new(unenvelope_body(response.body), response) end |
#disable(identity, options = {}) ⇒ Object
Immediately cancels all associated mandates and cancellable payments.
This will return a disable_failed error if the bank account has already been
disabled.
A disabled bank account can be re-enabled by creating a new bank account resource with the same details. Example URL: /customer_bank_accounts/:identity/actions/disable
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/gocardless_pro/services/customer_bank_accounts_service.rb', line 147 def disable(identity, = {}) path = sub_url('/customer_bank_accounts/:identity/actions/disable', { 'identity' => identity, }) params = .delete(:params) || {} [:params] = {} [:params]['data'] = params [:retry_failures] = false begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::CustomerBankAccount.new(unenvelope_body(response.body), response) end |
#get(identity, options = {}) ⇒ Object
Retrieves the details of an existing bank account. Example URL: /customer_bank_accounts/:identity
98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/gocardless_pro/services/customer_bank_accounts_service.rb', line 98 def get(identity, = {}) path = sub_url('/customer_bank_accounts/:identity', { 'identity' => identity, }) [:retry_failures] = true response = make_request(:get, path, ) return if response.body.nil? Resources::CustomerBankAccount.new(unenvelope_body(response.body), response) end |
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your bank accounts. Example URL: /customer_bank_accounts
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/gocardless_pro/services/customer_bank_accounts_service.rb', line 68 def list( = {}) path = '/customer_bank_accounts' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::CustomerBankAccount ) end |
#update(identity, options = {}) ⇒ Object
Updates a customer bank account object. Only the metadata parameter is allowed. Example URL: /customer_bank_accounts/:identity
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/gocardless_pro/services/customer_bank_accounts_service.rb', line 118 def update(identity, = {}) path = sub_url('/customer_bank_accounts/:identity', { 'identity' => identity, }) params = .delete(:params) || {} [:params] = {} [:params][envelope_key] = params [:retry_failures] = true response = make_request(:put, path, ) return if response.body.nil? Resources::CustomerBankAccount.new(unenvelope_body(response.body), response) end |