Class: GoCardlessPro::Services::ExportsService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::ExportsService
- Defined in:
- lib/gocardless_pro/services/exports_service.rb
Overview
Service for making requests to the Export endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#get(identity, options = {}) ⇒ Object
Returns a single export.
-
#list(options = {}) ⇒ Object
Returns a list of exports which are available for download.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
53 54 55 56 57 58 |
# File 'lib/gocardless_pro/services/exports_service.rb', line 53 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#get(identity, options = {}) ⇒ Object
Returns a single export. Example URL: /exports/:identity
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/gocardless_pro/services/exports_service.rb', line 18 def get(identity, = {}) path = sub_url('/exports/:identity', { 'identity' => identity }) [:retry_failures] = true response = make_request(:get, path, ) return if response.body.nil? Resources::Export.new(unenvelope_body(response.body), response) end |
#list(options = {}) ⇒ Object
Returns a list of exports which are available for download. Example URL: /exports
35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/gocardless_pro/services/exports_service.rb', line 35 def list( = {}) path = '/exports' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::Export ) end |