Class: GoCardlessPro::Services::OutboundPaymentImportsService
- Inherits:
-
BaseService
- Object
- BaseService
- GoCardlessPro::Services::OutboundPaymentImportsService
- Defined in:
- lib/gocardless_pro/services/outbound_payment_imports_service.rb
Overview
Service for making requests to the OutboundPaymentImport endpoints
Instance Method Summary collapse
-
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned.
-
#create(options = {}) ⇒ Object
Example URL: /outbound_payment_imports.
-
#get(identity, options = {}) ⇒ Object
Returns a single outbound payment import.
-
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your outbound payment imports.
Methods inherited from BaseService
#initialize, #make_request, #sub_url
Constructor Details
This class inherits a constructor from GoCardlessPro::Services::BaseService
Instance Method Details
#all(options = {}) ⇒ Object
Get a lazily enumerated list of all the items returned. This is similar to the list method but will paginate for you automatically.
Otherwise they will be the body of the request.
90 91 92 93 94 95 |
# File 'lib/gocardless_pro/services/outbound_payment_imports_service.rb', line 90 def all( = {}) Paginator.new( service: self, options: ).enumerator end |
#create(options = {}) ⇒ Object
Example URL: /outbound_payment_imports
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/gocardless_pro/services/outbound_payment_imports_service.rb', line 16 def create( = {}) path = '/outbound_payment_imports' params = .delete(:params) || {} [:params] = {} [:params][envelope_key] = params [:retry_failures] = true begin response = make_request(:post, path, ) # Response doesn't raise any errors until #body is called response.tap(&:body) rescue InvalidStateError => e if e.idempotent_creation_conflict? case @api_service.on_idempotency_conflict when :raise raise IdempotencyConflict.new(e.error) when :fetch return get(e.conflicting_resource_id) end end raise e end return if response.body.nil? Resources::OutboundPaymentImport.new(unenvelope_body(response.body), response) end |
#get(identity, options = {}) ⇒ Object
Returns a single outbound payment import. Example URL: /outbound_payment_imports/:identity
53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/gocardless_pro/services/outbound_payment_imports_service.rb', line 53 def get(identity, = {}) path = sub_url('/outbound_payment_imports/:identity', { 'identity' => identity, }) [:retry_failures] = true response = make_request(:get, path, ) return if response.body.nil? Resources::OutboundPaymentImport.new(unenvelope_body(response.body), response) end |
#list(options = {}) ⇒ Object
Returns a cursor-paginated (https://developer.gocardless.com/api-reference/#api-usage-cursor-pagination) list of your outbound payment imports. Example URL: /outbound_payment_imports
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/gocardless_pro/services/outbound_payment_imports_service.rb', line 72 def list( = {}) path = '/outbound_payment_imports' [:retry_failures] = true response = make_request(:get, path, ) ListResponse.new( response: response, unenveloped_body: unenvelope_body(response.body), resource_class: Resources::OutboundPaymentImport ) end |